// java wrapper for vtkExporter object
//

package vtk;
import vtk.*;

public class vtkExporter extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Write_2();
  public void Write()
    { Write_2(); }

  private native void Update_3();
  public void Update()
    { Update_3(); }

  private native void SetRenderWindow_4(vtkRenderWindow id0);
  public void SetRenderWindow(vtkRenderWindow id0)
    { SetRenderWindow_4(id0); }

  private native long GetRenderWindow_5();
  public vtkRenderWindow GetRenderWindow() {
    long temp = GetRenderWindow_5();

    if (temp == 0) return null;
    return (vtkRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetActiveRenderer_6(vtkRenderer id0);
  public void SetActiveRenderer(vtkRenderer id0)
    { SetActiveRenderer_6(id0); }

  private native long GetActiveRenderer_7();
  public vtkRenderer GetActiveRenderer() {
    long temp = GetActiveRenderer_7();

    if (temp == 0) return null;
    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInput_8(vtkRenderWindow id0);
  public void SetInput(vtkRenderWindow id0)
    { SetInput_8(id0); }

  private native long GetInput_9();
  public vtkRenderWindow GetInput() {
    long temp = GetInput_9();

    if (temp == 0) return null;
    return (vtkRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetStartWrite_10(Object id0, String id1);
  public void SetStartWrite(Object id0, String id1)
    { SetStartWrite_10(id0,id1); }

  private native void SetEndWrite_11(Object id0, String id1);
  public void SetEndWrite(Object id0, String id1)
    { SetEndWrite_11(id0,id1); }

  private native int GetMTime_12();
  public int GetMTime()
    { return GetMTime_12(); }

  public vtkExporter() { super(); }

  public vtkExporter(long id) { super(id); }

}
